IntoRawCStream

Trait IntoRawCStream 

pub trait IntoRawCStream {
    // Required method
    fn into_raw_c_stream(self) -> RawCStream;
}
A trait to express the ability to consume an object and acquire ownership of its raw stream.

Required Methods

fn into_raw_c_stream(self) -> RawCStream

Consumes this object, returning the raw underlying stream.

This function is typically used to transfer ownership of the underlying stream to the caller. When used in this way, callers are then the unique owners of the file descriptor and must close it once it’s no longer needed.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors